@@ -567,16 +567,42 @@ function RunSQL($sql_string, $table_prefix, $dbh)
 		
 		if (isset($class_sql) && ($class_sql != ""))
 		{
-			$table = $style_sheet . "_classes";
-			copy_table_structure($table, BWB_TABLE_PREFIX, $bwb_dbh, $bwb_database);
+			$class_table = $style_sheet . "_classes";
+			copy_table_structure($class_table, BWB_TABLE_PREFIX, $bwb_dbh, $bwb_database);
 			$result = $bwb_dbh->query($class_sql);
 		}
 		
 		if (isset($css_sql) && ($css_sql != ""))
 		{
-			$table = $style_sheet . "_css";
-			copy_table_structure($table, BWB_TABLE_PREFIX, $bwb_dbh, $bwb_database);
+			$site_css_table = $style_sheet . "_css";
+			copy_table_structure($site_css_table, BWB_TABLE_PREFIX, $bwb_dbh, $bwb_database);
 			$result = $bwb_dbh->query($css_sql);
+			
+			include ("build_css_string.php");
+			////////////////////////////////////////////////////////
+			/// Write menu items to menu.css file /////////////
+			//Test to see if file already exists.
+			if (BWB_BASE_DIR == '')
+				$userfiles = '';
+			else
+				$userfiles = "/" . BWB_BASE_DIR;
+				
+			$css_file = $style_sheet . ".css";
+			$file_name = $document_root . $userfiles . "/" . BWB_CSS_DIR . "/" . $css_file;
+				
+			if (file_exists($file_name))
+			{
+				$bkup_file_name = $file_name . time();
+				if (!rename($file_name, $bkup_file_name))
+					echo "Could not rename $file_name to $bkup_file_name.<br>";
+				@chmod($bkup_file_name, 0644);
+			}
+			
+			// Create file.
+			$fh = fopen($file_name, 'x') or die("Can't create $file_name: $php_errormsg");
+			$result = (fputs($fh, $css_string));
+			fclose($fh) or die($php_errormsg);
+			@chmod($file_name, 0644);
 		}
 		
 		if (isset($plugin_sql) && ($plugin_sql != ""))
