@@ -47,6 +47,8 @@
 // Added sorted output.
 // Revised: 12/30/2014	ELL
 // Added browser reset handling.
+// Revised: 1/12/2015	ELL
+// Replaced deprecated font-stretch with letter-spacing.
 //
 
 	if (BWB_BASE_DIR == "")
@@ -100,8 +102,12 @@
 		else $blink = 0;
 		if ($row_bs["linethrough"]) $linethrough = $row_bs["linethrough"];
 		else $linethrough = 0;
-		if ($row_bs["font_stretch"]) $font_stretch = $row_bs["font_stretch"];
-		else $font_stretch = "-not selected-";
+		//if ($row_bs["font_stretch"]) $font_stretch = $row_bs["font_stretch"];
+		//else $font_stretch = "-not selected-";
+		if ($row_bs["letter_spacing"]) $letter_spacing = $row_bs["letter_spacing"];
+		else $letter_spacing = -1000000;
+		if (isset($row_bs["letter_spacing_units"])) $letter_spacing_units = $row_bs["letter_spacing_units"];
+		else $letter_spacing_units = -1;
 		if ($row_bs["oblique"]) $oblique = $row_bs["oblique"];
 		else $oblique = 0;
 		if ($row_bs["small_caps"]) $small_caps = $row_bs["small_caps"];
@@ -120,8 +126,8 @@
 		else $shadow_blur = 0;
 		if (!is_null($row_bs["line_height"])) $line_height = $row_bs["line_height"];
 		else $line_height = -1;
-		if ($row_bs["line_height_units"]) $line_height_units = $row_bs["line_height_units"];
-		else $line_height_units = 0;
+		if (!is_null($row_bs["line_height_units"])) $line_height_units = $row_bs["line_height_units"];
+		else $line_height_units = -1;
 		
 		if ($row_bs["align"]) $align = $row_bs["align"];
 		else $align = "-not selected-";
@@ -364,22 +370,37 @@
 					$css_string .= "   text-shadow: " . $shadow_x_offset . "px " . $shadow_y_offset . "px " . $shadow_blur . "px;\n";
 			}
 			
-			if ($line_height != -1)
+			if ($line_height_units != -1)
 			{
 				if ($line_height_units == 0)
 					$css_string .= "   line-height: normal;\n";
-				elseif ($line_height_units == 1)		
+				elseif (($line_height_units == 1) && ($line_height != -1))
 					$css_string .= "   line-height: " . $line_height . ";\n";
-				elseif ($line_height_units == 2)		
+				elseif (($line_height_units == 2) && ($line_height != -1))
 					$css_string .= "   line-height: " . $line_height . "px;\n";
-				elseif ($line_height_units == 3)		
+				elseif (($line_height_units == 3) && ($line_height != -1))
 					$css_string .= "   line-height: " . $line_height . "%;\n";
-				elseif ($line_height_units == 4)		
+				elseif ($line_height_units == 4)
 					$css_string .= "   line-height: inherit;\n";
+				elseif ($line_height_units == 5)
+					$css_string .= "   line-height: initial;\n";
+			}
+				
+//			if (($font_stretch != "-not selected-") && ($font_stretch != "normal"))
+//				$css_string .= "   font-stretch: " . $font_stretch . ";\n";
+				
+			if ($letter_spacing_units != -1)
+			{
+				if (($letter_spacing_units == 1) && ($letter_spacing != -1000000))
+					$css_string .= "   letter-spacing: " . $letter_spacing . "px;\n";
+				elseif ($letter_spacing_units == 0)
+					$css_string .= "   letter-spacing: normal;\n";
+				elseif ($letter_spacing_units == 2)
+					$css_string .= "   letter-spacing: initial;\n";
+				elseif ($letter_spacing_units == 3)
+					$css_string .= "   letter-spacing: inherit;\n";
 			}
 				
-			if (($font_stretch != "-not selected-") && ($font_stretch != "normal"))
-				$css_string .= "   font-stretch: " . $font_stretch . ";\n";
 			if ($small_caps == 1)
 				$css_string .= "   font-variant: small-caps;\n";
 			if ($align != "-not selected-")
