@@ -537,7 +537,7 @@ function RunSQL($sql_string, $table_prefix, $dbh)
 		// Combine HTML (Javascript) code with default header content.
 		$header_content = $header_content . "\n\n\n" . $header_html;
 		$header_content = addslashes(stripslashes($header_content));
-		
+
 		// Check to see if head record alread exists.
 		$header_name = "header_" . $page_name;
 		$query = "SELECT page_name FROM " . BWB_TABLE_PREFIX . "page_data_special WHERE page_name = '$header_name'";
@@ -545,7 +545,7 @@ function RunSQL($sql_string, $table_prefix, $dbh)
 		$row_cnt = $result->rowCount();
 		if ($row_cnt > 0)
 			$header_name .= time();
-		
+
 		// Insert new header into table.
 		$query = "INSERT INTO " . BWB_TABLE_PREFIX . "page_data_special (page_name, page_content, `revised`, plugins) VALUES ('" . $header_name . "', '" . $header_content . "', '" . $today . "', '" . $plugin_id . "')";
 		$cnt = $bwb_dbh->exec($query);
@@ -554,7 +554,7 @@ function RunSQL($sql_string, $table_prefix, $dbh)
 		$header_str = "page_name='" . $header_name . "'";
 		$page_template = str_replace("page_name='header'", $header_str, $page_template);
 	}
-	
+
 	//If plugin is selected, then replace HTML footer holder with footer HTML code snippet.
 	if (($plugin != "-not selected-") && (isset($footer_html)) && ($footer_html != ""))
 	{
@@ -584,7 +584,7 @@ function RunSQL($sql_string, $table_prefix, $dbh)
 		$footer_str = "page_name='" . $footer_name . "'";
 		$page_template = str_replace("page_name='footer'", $footer_str, $page_template);
 	}
-	
+
 	//If plugin is selected, then append HTML code snippet to top.
 	if (($plugin != "-not selected-") && (isset($top_html)) && ($top_html != ""))
 	{
@@ -728,28 +728,58 @@ function RunSQL($sql_string, $table_prefix, $dbh)
 				$query = "INSERT INTO " . BWB_TABLE_PREFIX . "style_sheets SET `name`='" . $style_sheet . "', `description`='" . $style_sheet_description . "', `sort_order`=" . $sort_order;
 				$cnt = $bwb_dbh->exec($query);
 			}
+			
+			$query = "SELECT * FROM " . BWB_TABLE_PREFIX . "plugins WHERE `style_sheet`='" . $style_sheet . "' AND `deployed` = 1";
+			$result = $bwb_dbh->query($query);
+			if ($result->rowCount() < 1)
+			{
+				if (isset($class_sql) && ($class_sql != ""))
+				{
+					$class_table = $style_sheet . "_classes";
+					copy_table_structure($class_table, BWB_TABLE_PREFIX, $bwb_dbh, $bwb_database);
+					$result = $bwb_dbh->query($class_sql);
+				}
+				
+				if (isset($css_sql) && ($css_sql != ""))
+				{
+					$site_css_table = $style_sheet . "_css";
+					copy_table_structure($site_css_table, BWB_TABLE_PREFIX, $bwb_dbh, $bwb_database);
+					$result = $bwb_dbh->query($css_sql);
+					
+					include ("build_css_string.php");
+					////////////////////////////////////////////////////////
+					/// Write menu items to menu.css file /////////////
+					//Test to see if file already exists.
+					if (BWB_BASE_DIR == '')
+						$userfiles = '';
+					else
+						$userfiles = "/" . BWB_BASE_DIR;
+						
+					$css_file = $style_sheet . ".css";
+					$file_name = $document_root . $userfiles . "/" . BWB_CSS_DIR . "/" . $css_file;
+						
+					if (file_exists($file_name))
+					{
+						$bkup_file_name = $file_name . time();
+						if (!rename($file_name, $bkup_file_name))
+							echo "Could not rename $file_name to $bkup_file_name.<br>";
+						@chmod($bkup_file_name, 0644);
+					}
+					
+					// Create file.
+					$fh = fopen($file_name, 'x') or die("Can't create $file_name: $php_errormsg");
+					$result = (fputs($fh, $css_string));
+					fclose($fh) or die($php_errormsg);
+					@chmod($file_name, 0644);
+				}
+			}
 		}
-		
-		if (isset($class_sql) && ($class_sql != ""))
-		{
-			$table = $style_sheet . "_classes";
-			copy_table_structure($table, BWB_TABLE_PREFIX, $bwb_dbh, $bwb_database);
-			$result = $bwb_dbh->query($class_sql);
-		}
-		
-		if (isset($css_sql) && ($css_sql != ""))
-		{
-			$table = $style_sheet . "_css";
-			copy_table_structure($table, BWB_TABLE_PREFIX, $bwb_dbh, $bwb_database);
-			$result = $bwb_dbh->query($css_sql);
-		}
-		
+	
 		if (isset($plugin_sql) && ($plugin_sql != ""))
 		{
-//			$result = $bwb_dbh->query($plugin_sql);
 			RunSQL($plugin_sql, BWB_TABLE_PREFIX, $bwb_dbh);
 		}
-		
+	
 		$query = "UPDATE " . BWB_TABLE_PREFIX . "plugins SET `deployed`=1 WHERE `id`=$plugin";
 		$cnt = $bwb_dbh->exec($query);
 	}	
