@@ -50,6 +50,8 @@
 // Added drilling down one more directory level for building background image list.
 // Revised: 12/30/2014	ELL
 // Added browser CSS reset button.
+// Revised: 1/12/2015	ELL
+// Replaced deprecated font-stretch with letter-spacing.
 // 
 //
 	include ("check_session.php");
@@ -152,7 +154,9 @@ function PopulateForm(class_select)
 				document.getElementById("vertical_align").value = "-not selected-";
 				document.getElementById("display").value = "-not selected-";
 				document.getElementById("weight").value = "-not selected-";
-				document.getElementById("font_stretch").value = "-not selected-";
+				//document.getElementById("font_stretch").value = "-not selected-";
+				document.getElementById("letter_spacing").value = -1000000;
+				document.getElementById("letter_spacing_units").value = -1;
 				document.getElementById("italic").checked = false;
 				document.getElementById("underline").checked = false;
 				document.getElementById("overline").checked = false;
@@ -162,7 +166,7 @@ function PopulateForm(class_select)
 				document.getElementById("small_caps").checked = false;
 				document.getElementById("no_text_decoration").checked = false;
 				document.getElementById("line_height").value = -1;
-				document.getElementById("line_height_units").value = 0;
+				document.getElementById("line_height_units").value = -1;
 				
 				document.getElementById("shadow").checked = false;
 				document.getElementById("shadow_color").value = "-not set-";
@@ -293,7 +297,9 @@ function PopulateForm(class_select)
 				document.getElementById("vertical_align").value = JSON_row.vertical_align;
 				document.getElementById("display").value = JSON_row.display;
 				document.getElementById("weight").value = JSON_row.weight;
-				document.getElementById("font_stretch").value = JSON_row.font_stretch;
+				//document.getElementById("font_stretch").value = JSON_row.font_stretch;
+				document.getElementById("letter_spacing").value = JSON_row.letter_spacing;
+				document.getElementById("letter_spacing_units").value = JSON_row.letter_spacing_units;
 				if (JSON_row.italic == 1)
 					document.getElementById("italic").checked = true;
 				else
@@ -470,30 +476,10 @@ function PopulateForm(class_select)
 				UpdateImage(2);
 			}
 			var heading_str = document.getElementById("goto_class").value;
-			heading_str = heading_str.replace("PERIOD", ".");
-			heading_str = heading_str.replace("POUND", "#");
-			heading_str = heading_str.replace("SPACE", " ");
-			heading_str = heading_str.replace("COMMA", ",");
-			heading_str = heading_str.replace("PERIOD", ".");
-			heading_str = heading_str.replace("POUND", "#");
-			heading_str = heading_str.replace("SPACE", " ");
-			heading_str = heading_str.replace("COMMA", ",");
-			heading_str = heading_str.replace("PERIOD", ".");
-			heading_str = heading_str.replace("POUND", "#");
-			heading_str = heading_str.replace("SPACE", " ");
-			heading_str = heading_str.replace("COMMA", ",");
-			heading_str = heading_str.replace("PERIOD", ".");
-			heading_str = heading_str.replace("POUND", "#");
-			heading_str = heading_str.replace("SPACE", " ");
-			heading_str = heading_str.replace("COMMA", ",");
-			heading_str = heading_str.replace("PERIOD", ".");
-			heading_str = heading_str.replace("POUND", "#");
-			heading_str = heading_str.replace("SPACE", " ");
-			heading_str = heading_str.replace("COMMA", ",");
-			heading_str = heading_str.replace("PERIOD", ".");
-			heading_str = heading_str.replace("POUND", "#");
-			heading_str = heading_str.replace("SPACE", " ");
-			heading_str = heading_str.replace("COMMA", ",");
+			heading_str = heading_str.replace(/PERIOD/g, ".");
+			heading_str = heading_str.replace(/POUND/g, "#");
+			heading_str = heading_str.replace(/SPACE/g, " ");
+			heading_str = heading_str.replace(/COMMA/g, ",");
 			document.getElementById("class_heading").innerHTML = heading_str;
 				
 			enable_disable_controls(0);
@@ -544,7 +530,9 @@ function UpdateCSS()
 		params = params + "&vertical_align=" + document.getElementById("vertical_align").value;
 		params = params + "&display=" + document.getElementById("display").value;
 		params = params + "&weight=" + document.getElementById("weight").value;
-		params = params + "&font_stretch=" + document.getElementById("font_stretch").value;
+		//params = params + "&font_stretch=" + document.getElementById("font_stretch").value;
+		params = params + "&letter_spacing=" + document.getElementById("letter_spacing").value;
+		params = params + "&letter_spacing_units=" + document.getElementById("letter_spacing_units").value;
 		if (document.getElementById("italic").checked == true) params = params + "&italic=1";
 		else params = params + "&italic=0";
 		if (document.getElementById("underline").checked == true) params = params + "&underline=1";
@@ -905,9 +893,18 @@ function UpdateCSS()
 					   <option value="900">900</option>
 					   </select>
 					  </td>
-					  <td align="right">Font Stretch:</td>
+					  <td align="right">Letter Spacing:</td>
 					  <td>
-					   <select name="font_stretch" id="font_stretch">
+                       <input name="letter_spacing" type="text" id="letter_spacing" value="" size="6">
+					   <select name="letter_spacing_units" id="letter_spacing_units" onChange="CheckLetterSpacing(this);">
+					   <option value="-1">-not selected-</option>
+					   <option value="0">Normal</option>
+					   <option value="1">px</option>
+					   <option value="2">Initial</option>
+					   <option value="3">Inherit</option>
+					   </select>
+                       <!--
+                       <select name="font_stretch" id="font_stretch">
 					   <option value="-not selected-">-not selected-</option>
 					   <option value="normal">Normal</option>
 					   <option value="wider">Wider</option>
@@ -921,16 +918,19 @@ function UpdateCSS()
 					   <option value="extra-expanded">Extra-Expanded</option>
 					   <option value="ultra-expanded">Ultra-Expanded</option>
 					   </select>
+                       -->
 					  </td>  
 					  <td align="right">Line Height: </td>
 					  <td colspan="2" >
 					   <input name="line_height" type="text" id="line_height" value="" size="6">
                        <select name="line_height_units" id="line_height_units" onChange="CheckLineHeight(this);">
+                       		<option value="-1">-not selected-</option>
 						    <option value="0">Normal</option>
 						    <option value="1">Multiplier</option>
                             <option value="2">px</option>
                             <option value="3">%</option>
                             <option value="4">Inherit</option>
+                            <option value="5">Initial</option>
 						</select>
 					  </td>
 					  <td class="small_message" align="right" valign="bottom">Click &quot;None&quot; only to explicitly enforce no text decoration.</td>
