@@ -239,18 +239,30 @@ if ($_POST['use_captcha'])
 									$_POST["recaptcha_challenge_field"],
 									$_POST["recaptcha_response_field"]);
 	
-	  if (!$resp->is_valid) {
-			// Verification code is incorrect.
-			$captcha_err = true;
-		}
+	  if (!$resp->is_valid)
+			$captcha_err = true;	// Verification code is incorrect.
+	}
+	elseif ($_POST['captcha_type'] == "recaptcha2")
+	{
+		include("../connect/captchakeys.php");
+		require_once('recaptchalib2.php');
+		// The response from reCAPTCHA
+		$resp = null;
+		// The error code from reCAPTCHA, if any
+		$error = null;
+		$reCaptcha = new ReCaptcha(RECAPTCHA_SECRET);
+		// Was there a reCAPTCHA response?
+		if ($_POST["g-recaptcha-response"])
+			$resp = $reCaptcha->verifyResponse($_SERVER["REMOTE_ADDR"],	$_POST["g-recaptcha-response"]);
+		// reCAPTCHA response correct?
+		if (($resp == null) || !($resp->success))
+			$captcha_err = true;	// Verification code is incorrect.
 	}
 	elseif ($_POST['captcha_type'] == "wscaptcha")	// Requires purchase of PHP Captcha from http://webspamprotect.com/
 	{
 		require_once("wspcaptchalib.php");
-		if (!WSP_CheckCAPTCHA()) {
-			// Verification code is incorrect.
-			$captcha_err = true;
-		}
+		if (!WSP_CheckCAPTCHA())
+			$captcha_err = true;	// Verification code is incorrect.
 	}
 	elseif ($_POST['captcha_type'] == "mollom")	// Requires acquisition of public and private keys from http://mollom.com
 	{
