@@ -17,6 +17,8 @@
 // Added ability to present plugin buttons to bloggers and restricted users if plugin access set to blogger or restricted.
 // Revised: 11/17/2014	ELL
 // Added new button for editing files.
+// Revised: 1/13/2015	ELL
+// Added NEW SESSION button to allow easy editing of multiple items.
 	
 	include ("check_session.php");
 	
@@ -135,6 +137,10 @@
 	background-image:url(images/help_mo.png);
 	cursor:pointer;
 }
+
+#username	{
+	right: <?php if (($access_level == "power_user") || ($access_level == "admin")) echo "350"; else echo "190"; ?>px;
+}
 </style>
 
 <script language="javascript" type="text/javascript" src="js/ajax.js"></script>
@@ -313,6 +319,10 @@ var enable_wizard = '<?php echo $enable_wizard; ?>';
 <div id="access_level">Access Level: <span class="access_level"><?php echo $access_level; ?></span></div>
 <div id="username"> Welcome <?php if (($first_name != "") || ($last_name != "")) echo $first_name . " " . $last_name; else echo $userid; ?></div>
 
+<?php if (($access_level == "power_user") || ($access_level == "admin"))	{	?>
+<div class="button_heading_top_level new_session" id="btn_new_session" onClick="window.open('main.php');"><span class="button_heading_text_top_level new_session">NEW SESSION</span></div>
+<?php }	?>
+
 <div class="button_heading_top_level logout" id="btn_logout" onClick="window.location='index.php';"><span class="button_heading_text_top_level logout">LOGOUT</span></div>
 
 
