@@ -203,7 +203,7 @@ footer<input type="text" name="suffix" style="width:100px;" value="<?php echo $n
 			
 			if (!file_exists($file_name))
 			{
-				echo "Error: $file_name does not exists.  Click <a href=\"manage_special.php\" title=\"here\">here</a> to return to the area assignment page.";
+				echo "Error: $file_name does not exist.  Click <a href=\"manage_special.php\" title=\"here\">here</a> to return to the area assignment page.";
 				exit;
 			}
 	
